embassy-usb

Crates

git

Versions

default

Flavors

MidiClassConfig

Struct MidiClassConfig 

#[non_exhaustive]
pub struct MidiClassConfig { pub n_in_jacks: u8, pub n_out_jacks: u8, pub max_packet_size: u16, }
Configuration for the MIDI class.

For the jacks, the field names use the terminology used by the USB specification, which defines the direction from the perspective of the host.

This struct also implements the Default trait with the most common setup: 1 input jack, 1 output jack and a maximum packet size of 64.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
n_in_jacks: u8

Number of jacks for sending data to the host via the IN endpoint. If set to 0, the IN endpoint will not be allocated.

n_out_jacks: u8

Number of jacks for receiving data from the host via the OUT endpoint. If set to 0, the OUT endpoint will not be allocated.

max_packet_size: u16

Maximum packet size for the endpoints. For full-speed devices, the value has to be one of 8, 16, 32 or 64.